@@ -1,31 +1,20 @@
 import importlib
 from subprocess import run
-from time import sleep
 from typing import Optional
 
 from cloudpathlib import CloudPath
 from lamin_logger import logger
 from packaging import version
 
-from ._clone import clone_test, setup_local_test_postgres, setup_local_test_sqlite_file
+from ._clone import clone_test, setup_local_test_sqlite_file
 from ._settings_instance import InstanceSettings
 from ._setup_instance import init
 from ._test_instances import test_instances
 
 
-# we currently need to run this in to separate processes for sqlite and for postgres
-# because of schemas being different at import time
 def migrate_test(
     schema_package: str, n_instances: Optional[int] = None, dialect_name="sqlite"
 ):
-    # this is super hacky, we shouldn't need to set up these test instances here
-    if dialect_name == "sqlite":
-        init(storage="testdb")
-    elif dialect_name == "postgresql":
-        connection_string = setup_local_test_postgres()
-        sleep(2)
-        init(storage="testdb", dbconfig=connection_string)
-        run("docker stop pgtest && docker rm pgtest", shell=True)
     # auto-bump version to simulate state after release
     schema_module = importlib.import_module(schema_package)
     v = version.parse(schema_module.__version__)
